import React, { PropTypes as PT } from 'react';

import css from '../../styles/game.css';

export function UnityEmbed(_ref) {
	var content = _ref.content;

	var unityInstalled = typeof navigator !== 'undefined' && navigator.mimeTypes && navigator.mimeTypes['application/vnd.unity'] && navigator.mimeTypes['application/vnd.unity'].enabledPlugin && navigator.plugins && navigator.plugins['Unity Player'];

	if (!unityInstalled) {
		return React.createElement(
			'div',
			{ className: css.notInstalled },
			React.createElement(
				'p',
				null,
				'Unity Web Player not installed.'
			)
		);
	}

	return React.createElement('embed', {
		type: 'application/vnd.unity',
		className: css.game,
		src: content
	});
}

UnityEmbed.propTypes = {
	content: PT.string
};

export default function Game(_ref2) {
	var className = _ref2.className,
	    content = _ref2.content,
	    height = _ref2.height,
	    type = _ref2.type,
	    width = _ref2.width;

	var classes = [css.container];
	if (className) {
		classes.push(className);
	}

	var padding = height / width * 100;

	return React.createElement(
		'div',
		{ className: classes.join(' '), style: { maxWidth: width } },
		React.createElement('div', { style: { paddingBottom: padding + '%' } }),
		type === 'flash' ? React.createElement(
			'object',
			{ data: content, className: css.game },
			React.createElement('param', { name: 'movie', value: content }),
			React.createElement('param', { name: 'allowScriptAccess', value: 'always' }),
			React.createElement('param', { name: 'allowNetworking', value: 'internal' })
		) : type === 'unity' ? React.createElement(UnityEmbed, { content: content }) : type === 'iframe' ? React.createElement('iframe', { src: content, width: width, height: height, className: css.game }) : type === 'custom' ? React.createElement('div', { dangerouslySetInnerHTML: { __html: content } }) : 'unsupported game type'
	);
}

Game.propTypes = {
	/**
  * Additional class names
  */
	className: PT.string,

	/**
  * URL to the content
  */
	content: PT.string.isRequired,

	/**
  * Height of the game
  */
	height: PT.number.isRequired,

	/**
  * Type of the game
  */
	type: PT.oneOf(['flash', 'unity', 'iframe']).isRequired,

	/**
  * Width of the game
  */
	width: PT.number.isRequired
};