var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import debounce from 'just-debounce';
import React from 'react';

import InputText from './InputText';
import css from '../../../styles/input.css';

var PT = React.PropTypes;

/**
 * Autocomplete input
 */

var InputAutocomplete = function (_React$Component) {
	_inherits(InputAutocomplete, _React$Component);

	function InputAutocomplete(_ref) {
		var timeout = _ref.timeout;

		_classCallCheck(this, InputAutocomplete);

		var _this = _possibleConstructorReturn(this, (InputAutocomplete.__proto__ || Object.getPrototypeOf(InputAutocomplete)).call(this));

		_this.state = {
			dropdownOpen: false,
			options: [],
			selected: 0
		};

		_this.debouncedShowOptions = debounce(_this.showOptions, timeout);
		_this.handleChange = _this.handleChange.bind(_this);
		_this.handleClick = _this.handleClick.bind(_this);
		_this.handleKeyDown = _this.handleKeyDown.bind(_this);
		return _this;
	}

	_createClass(InputAutocomplete, [{
		key: 'getOptions',
		value: function getOptions(query) {
			var _this2 = this;

			var url = this.props.endpoint.replace('%s', encodeURIComponent(query));

			return fetch(url, { method: 'get' }).then(function (res) {
				return res.json();
			}).then(function (json) {
				return Promise.resolve(_this2.props.createOptions(json));
			});
		}
	}, {
		key: 'selectOption',
		value: function selectOption(index) {
			this.setState({ dropdownOpen: false });
			this.props.change(this.state.options[index]);
		}
	}, {
		key: 'showOptions',
		value: function showOptions(query) {
			var _this3 = this;

			this.getOptions(query).then(function () {
				var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];

				_this3.setState({ dropdownOpen: true, options: options });
			});
		}
	}, {
		key: 'handleChange',
		value: function handleChange(ev) {
			var query = ev.target.value;
			this.setState({ value: query });

			if (query.length < this.props.minLength) {
				this.setState({ dropdownOpen: false });
				return;
			}

			this.debouncedShowOptions(query);
		}
	}, {
		key: 'handleClick',
		value: function handleClick(ev) {
			this.selectOption(parseInt(ev.target.dataset.index, 10));
		}
	}, {
		key: 'handleKeyDown',
		value: function handleKeyDown(ev) {
			var keys = ['ArrowDown', 'ArrowUp', 'Enter', 'Escape'];
			if (keys.indexOf(ev.key) === -1) return;

			if (ev.key === 'Escape') {
				this.setState({ dropdownOpen: false });
				return;
			}

			ev.preventDefault();
			var selected = this.state.selected;

			if (ev.key === 'Enter') {
				this.selectOption(this.state.selected);
				return;
			}

			if (!this.state.dropdownOpen) {
				this.setState({ dropdownOpen: true });
				return;
			}

			if (ev.key === 'ArrowDown') selected++;
			if (ev.key === 'ArrowUp') selected--;

			if (selected < 0) {
				selected = this.state.options.length - 1;
			}

			if (selected > this.state.options.length - 1) {
				selected = 0;
			}

			this.setState({ selected: selected });
		}
	}, {
		key: 'render',
		value: function render() {
			var _this4 = this;

			var props = _objectWithoutProperties(this.props, []);

			var _state = this.state,
			    dropdownOpen = _state.dropdownOpen,
			    options = _state.options,
			    selected = _state.selected;


			delete props.createOptions;
			delete props.endpoint;
			delete props.timeout;

			return React.createElement(
				InputText,
				_extends({}, props, {
					onChange: this.handleChange,
					onKeyDown: this.handleKeyDown
				}),
				dropdownOpen && React.createElement(
					'ul',
					{ className: css.dropdown },
					options.map(function (option, index) {
						return React.createElement(
							'li',
							{
								key: index,
								'data-index': index,
								className: selected === index ? css.selectedOption : '',
								onClick: _this4.handleClick
							},
							option
						);
					})
				)
			);
		}
	}]);

	return InputAutocomplete;
}(React.Component);

InputAutocomplete.propTypes = {
	/**
  * Function which will be called whenever the value of the field changes.
  */
	change: PT.func.isRequired,

	/**
  * Function to compile options from the json returned by the called
  * endpoint. This function should return an array of strings.
  */
	createOptions: PT.func.isRequired,

	/**
  * The endpoint to call to fetch possible options for the autocomplete.
  * The string `%s` will be replaced by the user's input.
  */
	endpoint: PT.string.isRequired,

	/**
  * Minimum length of input to start searching from
  */
	minLength: PT.number,

	/**
  * Time to wait after user's last input to start searching
  */
	timeout: PT.number
};
InputAutocomplete.defaultProps = {
	minLength: 3,
	timeout: 200
};
export default InputAutocomplete;