var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { PropTypes as PT } from 'react';

import css from '../../../styles/input.css';
import wrapWithField from '../../utils/wrapWithField';

/**
 * Text input capable of rendering each HTML5 input type.
 * The input is automatically wrapped inside a `<Field>` so
 * you can also specify properties belonging to `Field` such
 * as `error` or `label`.
 *
 * Any properties which are not used by either `Field` or `InputText`
 * will get passed to the actual `<input />` element.
 *
 * This input is optimised in order to be used together with
 * `react-redux-formal` for form management, so it handles the
 * `change` function which is injected by the library.
 */
export var InputText = function (_React$Component) {
	_inherits(InputText, _React$Component);

	function InputText() {
		_classCallCheck(this, InputText);

		var _this = _possibleConstructorReturn(this, (InputText.__proto__ || Object.getPrototypeOf(InputText)).call(this));

		_this.state = { hasFocus: false };

		_this.handleBlur = _this.handleBlur.bind(_this);
		_this.handleChange = _this.handleChange.bind(_this);
		_this.handleFocus = _this.handleFocus.bind(_this);
		return _this;
	}

	_createClass(InputText, [{
		key: 'handleBlur',
		value: function handleBlur(ev) {
			this.props.validate(ev.target.value);

			this.setState({ hasFocus: false });

			if (this.props.onBlur) {
				this.props.onBlur(ev);
			}
		}
	}, {
		key: 'handleChange',
		value: function handleChange(ev) {
			this.props.change(ev.target.value);

			if (this.props.onChange) {
				this.props.onChange(ev);
			}
		}
	}, {
		key: 'handleFocus',
		value: function handleFocus(ev) {
			this.setState({ hasFocus: true });

			if (this.props.onFocus) {
				this.props.onFocus(ev);
			}
		}
	}, {
		key: 'render',
		value: function render() {
			var _props = this.props,
			    children = _props.children,
			    component = _props.component,
			    props = _objectWithoutProperties(_props, ['children', 'component']);

			delete props.change;
			delete props.validate;

			var classes = [css.container];
			if (this.state.hasFocus) {
				classes.push(css.hasFocus);
			}

			return React.createElement(
				'div',
				{ className: classes.join(' ') },
				React.createElement(component, _extends({}, props, {
					className: css.input,
					onBlur: this.handleBlur,
					onChange: this.handleChange,
					onFocus: this.handleFocus
				})),
				children
			);
		}
	}]);

	return InputText;
}(React.Component);

InputText.propTypes = {
	/**
  * Function to call with the field's updated value
  */
	change: PT.func.isRequired,

	/**
  * Children of the input
  */
	children: PT.node,

	/**
  * Component to render
  */
	component: PT.oneOf(['input', 'textarea']),

	/**
  * Function to call with the input's blur event
  */
	onBlur: PT.func,

	/**
  * Function to call with the input's change event
  */
	onChange: PT.func,

	/**
  * Function to call with the input's focus event
  */
	onFocus: PT.func,

	/**
  * Type of input, accepts all valid HTML5 input types
  */
	type: PT.string,

	/**
  * Function to call to validate the field
  */
	validate: PT.func.isRequired
};
InputText.defaultProps = {
	component: 'input',
	type: 'text'
};
export default wrapWithField(InputText);